@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -124,7 +124,9 @@ class GrafeasAsyncClient:
     )
 
     def __init__(
-        self, *, transport: Union[str, GrafeasTransport] = "grpc_asyncio",
+        self,
+        *,
+        transport: Union[str, GrafeasTransport] = "grpc_asyncio",
     ) -> None:
         """Instantiate the grafeas client.
 
@@ -137,7 +139,9 @@ class GrafeasAsyncClient:
                 creation failed for any reason.
         """
 
-        self._client = GrafeasClient(transport=transport,)
+        self._client = GrafeasClient(
+            transport=transport,
+        )
 
     async def get_occurrence(
         self,
@@ -154,9 +158,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_get_occurrence():
+            async def sample_get_occurrence():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.GetOccurrenceRequest(
@@ -164,7 +168,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_occurrence(request=request)
+                response = await client.get_occurrence(request=request)
 
                 # Handle the response
                 print(response)
@@ -233,7 +237,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -254,9 +263,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_list_occurrences():
+            async def sample_list_occurrences():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.ListOccurrencesRequest(
@@ -267,7 +276,7 @@ class GrafeasAsyncClient:
                 page_result = client.list_occurrences(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -343,12 +352,20 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListOccurrencesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -367,14 +384,13 @@ class GrafeasAsyncClient:
         this method to delete an occurrence when the occurrence
         is no longer applicable for the given resource.
 
-
         .. code-block:: python
 
             from grafeas import grafeas_v1
 
-            def sample_delete_occurrence():
+            async def sample_delete_occurrence():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.DeleteOccurrenceRequest(
@@ -382,7 +398,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                client.delete_occurrence(request=request)
+                await client.delete_occurrence(request=request)
 
         Args:
             request (Union[grafeas.grafeas_v1.types.DeleteOccurrenceRequest, dict]):
@@ -443,7 +459,10 @@ class GrafeasAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def create_occurrence(
@@ -462,9 +481,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_create_occurrence():
+            async def sample_create_occurrence():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.CreateOccurrenceRequest(
@@ -472,7 +491,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_occurrence(request=request)
+                response = await client.create_occurrence(request=request)
 
                 # Handle the response
                 print(response)
@@ -539,7 +558,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -560,9 +584,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_batch_create_occurrences():
+            async def sample_batch_create_occurrences():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.BatchCreateOccurrencesRequest(
@@ -570,7 +594,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.batch_create_occurrences(request=request)
+                response = await client.batch_create_occurrences(request=request)
 
                 # Handle the response
                 print(response)
@@ -640,7 +664,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -662,9 +691,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_update_occurrence():
+            async def sample_update_occurrence():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.UpdateOccurrenceRequest(
@@ -672,7 +701,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.update_occurrence(request=request)
+                response = await client.update_occurrence(request=request)
 
                 # Handle the response
                 print(response)
@@ -745,7 +774,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -763,14 +797,13 @@ class GrafeasAsyncClient:
         Consumer projects can use this method to get a note that
         belongs to a provider project.
 
-
         .. code-block:: python
 
             from grafeas import grafeas_v1
 
-            def sample_get_occurrence_note():
+            async def sample_get_occurrence_note():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.GetOccurrenceNoteRequest(
@@ -778,7 +811,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_occurrence_note(request=request)
+                response = await client.get_occurrence_note(request=request)
 
                 # Handle the response
                 print(response)
@@ -848,7 +881,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -868,9 +906,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_get_note():
+            async def sample_get_note():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.GetNoteRequest(
@@ -878,7 +916,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_note(request=request)
+                response = await client.get_note(request=request)
 
                 # Handle the response
                 print(response)
@@ -947,7 +985,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -968,9 +1011,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_list_notes():
+            async def sample_list_notes():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.ListNotesRequest(
@@ -981,7 +1024,7 @@ class GrafeasAsyncClient:
                 page_result = client.list_notes(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1057,12 +1100,20 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListNotesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1083,9 +1134,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_delete_note():
+            async def sample_delete_note():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.DeleteNoteRequest(
@@ -1093,7 +1144,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                client.delete_note(request=request)
+                await client.delete_note(request=request)
 
         Args:
             request (Union[grafeas.grafeas_v1.types.DeleteNoteRequest, dict]):
@@ -1154,7 +1205,10 @@ class GrafeasAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def create_note(
@@ -1174,9 +1228,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_create_note():
+            async def sample_create_note():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.CreateNoteRequest(
@@ -1185,7 +1239,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_note(request=request)
+                response = await client.create_note(request=request)
 
                 # Handle the response
                 print(response)
@@ -1259,7 +1313,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1269,7 +1328,7 @@ class GrafeasAsyncClient:
         request: Union[grafeas.BatchCreateNotesRequest, dict] = None,
         *,
         parent: str = None,
-        notes: Sequence[grafeas.BatchCreateNotesRequest.NotesEntry] = None,
+        notes: Mapping[str, grafeas.Note] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -1280,9 +1339,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_batch_create_notes():
+            async def sample_batch_create_notes():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.BatchCreateNotesRequest(
@@ -1290,7 +1349,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.batch_create_notes(request=request)
+                response = await client.batch_create_notes(request=request)
 
                 # Handle the response
                 print(response)
@@ -1306,7 +1365,7 @@ class GrafeasAsyncClient:
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            notes (:class:`Sequence[grafeas.grafeas_v1.types.BatchCreateNotesRequest.NotesEntry]`):
+            notes (:class:`Mapping[str, grafeas.grafeas_v1.types.Note]`):
                 The notes to create. Max allowed
                 length is 1000.
 
@@ -1358,7 +1417,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1380,9 +1444,9 @@ class GrafeasAsyncClient:
 
             from grafeas import grafeas_v1
 
-            def sample_update_note():
+            async def sample_update_note():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.UpdateNoteRequest(
@@ -1390,7 +1454,7 @@ class GrafeasAsyncClient:
                 )
 
                 # Make the request
-                response = client.update_note(request=request)
+                response = await client.update_note(request=request)
 
                 # Handle the response
                 print(response)
@@ -1463,7 +1527,12 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1483,14 +1552,13 @@ class GrafeasAsyncClient:
         occurrences across consumer projects referencing the
         specified note.
 
-
         .. code-block:: python
 
             from grafeas import grafeas_v1
 
-            def sample_list_note_occurrences():
+            async def sample_list_note_occurrences():
                 # Create a client
-                client = grafeas_v1.GrafeasClient()
+                client = grafeas_v1.GrafeasAsyncClient()
 
                 # Initialize request argument(s)
                 request = grafeas_v1.ListNoteOccurrencesRequest(
@@ -1501,7 +1569,7 @@ class GrafeasAsyncClient:
                 page_result = client.list_note_occurrences(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -1579,12 +1647,20 @@ class GrafeasAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListNoteOccurrencesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1599,7 +1675,9 @@ class GrafeasAsyncClient:
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution("grafeas",).version,
+        gapic_version=pkg_resources.get_distribution(
+            "grafeas",
+        ).version,
     )
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
