@@ -372,6 +372,8 @@ class VulnerabilityOccurrence(proto.Message):
                 severity for this vulnerability when that is
                 available and note provider assigned severity
                 when it is not available.
+            file_location (Sequence[grafeas.grafeas_v1.types.FileLocation]):
+                The location at which this package was found.
         """
 
         affected_cpe_uri = proto.Field(
@@ -413,6 +415,11 @@ class VulnerabilityOccurrence(proto.Message):
             number=9,
             enum=g_severity.Severity,
         )
+        file_location = proto.RepeatedField(
+            proto.MESSAGE,
+            number=10,
+            message=common.FileLocation,
+        )
 
     type_ = proto.Field(
         proto.STRING,
